@@ -18,9 +18,9 @@ def core(obj):
 	return pal
 	print('\nuser switch engine:', core.__name__)    
 
-def asnumpy(arr): return pal.cpu(arr)
+def asnumpy(arr, **key): return pal.cpu(arr, **key)
 
-def asarray(arr): return pal.asarray(arr)
+def asarray(arr, **key): return pal.asarray(arr, **key)
 
 try:
     import cupy
