@@ -115,22 +115,6 @@ def onnx2planer(path):
     with zipfile.ZipFile(path.replace('onnx', 'pla'), 'w') as f:
         f.write(path.replace('onnx','json'))
         f.write(path.replace('onnx','npy'))
-    
-    
-
-def torch2planer(net, name, x, in_name=None, out_name=None):
-    import torch
-    import sys
-    np.save(name+'.npy', get_weight(net))
-    stdout = sys.stdout
-    sys.stdout = open(name+'.txt', 'w')
-    torch.onnx.export(net, x, 'useless.onnx', verbose=True,
-        input_names=in_name, output_names=out_name)
-    sys.stdout = stdout
-    body, flow = read_onnx(name)
-    # the json file is needed
-    with open(name+'.json', 'w') as jsfile:
-        json.dump({'layers':body, 'flow':flow}, jsfile)
 
 if __name__ == '__main__':
     a, b = read_onnx('../demo/yolov3-planer-2/yolov3')
